Release notes
=============

This project uses `semantic versioning <http://semver.org/>`_.

0.4.0
-----

Changed
^^^^^^^

- Qualified blocks now preserve indentation.

0.3.0
-----

Fixed
^^^^^

- Unclosed qualified blocks get removed.
- Whitespace is stripped when uncommenting.

Changed
^^^^^^^

- ``IteratorQueue`` and ``CommentPrefix`` are now private, as they are
  implementation details.

0.2.0
-----

Initial release.
